pub struct MappedBufferGuard<M: RawMutex + 'static, U: ?Sized> { /* private fields */ }Expand description
Like BufferGuard, but derefs to a borrowed U (often a slice or inner field).
Dropping this guard marks the same pool index free as the original BufferGuard.
Implementations
Sourceimpl<M: RawMutex + 'static, U: ?Sized> MappedBufferGuard<M, U>
impl<M: RawMutex + 'static, U: ?Sized> MappedBufferGuard<M, U>
Sourcepub fn map<V: ?Sized>(
orig: Self,
fun: impl FnOnce(&mut U) -> &mut V,
) -> MappedBufferGuard<M, V>
pub fn map<V: ?Sized>( orig: Self, fun: impl FnOnce(&mut U) -> &mut V, ) -> MappedBufferGuard<M, V>
Chains BufferGuard::map: re-borrows &mut U into &mut V without releasing the
pool slot until the final mapped guard is dropped.
Same as BufferGuard::map: orig: Self instead of self, so call
MappedBufferGuard::map(guard, f) and keep guard.map(...) available for U::map
via Deref / DerefMut.